@@ -16,7 +16,7 @@ import warnings
 from typing_extensions import Literal
 
 from ..._types import Body, Query, Headers
-from ..._utils._utils import with_sts_token, async_with_sts_token
+from ..._utils._utils import deepcopy_minimal, with_sts_token, async_with_sts_token
 from ..._utils._key_agreement import aes_gcm_decrypt_base64_string
 from ..._base_client import make_request_options
 from ..._resource import SyncAPIResource, AsyncAPIResource
@@ -179,6 +179,7 @@ class Completions(SyncAPIResource):
             and extra_headers.get(ARK_E2E_ENCRYPTION_HEADER, None) == "true"
         ):
             is_encrypt = True
+            messages = deepcopy_minimal(messages)
             e2e_key, e2e_nonce = self._encrypt(model, messages, extra_headers)
 
         resp = self._post(
@@ -327,6 +328,7 @@ class AsyncCompletions(AsyncAPIResource):
             and extra_headers.get(ARK_E2E_ENCRYPTION_HEADER, None) == "true"
         ):
             is_encrypt = True
+            messages = deepcopy_minimal(messages)
             e2e_key, e2e_nonce = self._encrypt(model, messages, extra_headers)
 
         resp = await self._post(
