@@ -1,14 +1,15 @@
 from __future__ import annotations
 
-from typing import Optional
+from typing import Optional, Union, Iterable
 
 from typing_extensions import Literal, Required, TypedDict
+from .chat_completion_content_part_param import ChatCompletionContentPartParam
 
 __all__ = ["ChatCompletionToolMessageParam"]
 
 
 class ChatCompletionToolMessageParam(TypedDict, total=False):
-    content: Required[str]
+    content: Required[Union[str, Iterable[ChatCompletionContentPartParam]]]
     """The contents of the tool message."""
 
     role: Required[Literal["tool"]]
